==> open-xchange-server_6.10.0.0.orig.tar.gz: open-xchange-server-6.10.0.0/src/com/openexchange/tools/versit/valuedefinitions/rfc2425/ListValueDefinition.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.versit.valuedefinitions.rfc2425;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import com.openexchange.tools.versit.Property;
import com.openexchange.tools.versit.StringScanner;
import com.openexchange.tools.versit.ValueDefinition;

/**
 * @author Viktor Pracht
 */
public class ListValueDefinition extends ValueDefinition {

    private final char Separator;

    private final ValueDefinition Definition;

    public ListValueDefinition(final char separator, final ValueDefinition definition) {
        Separator = separator;
        Definition = definition;
    }

    @Override
    public Object createValue(final StringScanner s, final Property property) throws IOException {
        final ArrayList<Object> retval = new ArrayList<Object>();
        while (true) {
            final Object val = Definition.createValue(s, property);
            if (val != null) {
                retval.add(val);
            }
            if (val == null || s.peek != Separator) {
                break;
            }
            s.read();
        }
        return retval.isEmpty() ? null : retval;
    }

    @Override
    public String writeValue(final Object value) {
        final List<?> list = (ArrayList<?>) value;
        final int count = list.size();
        if (count == 0) {
            return "";
        }
        final StringBuilder sb = new StringBuilder();
        Object val = list.get(0);
        if (val != null) {
            sb.append(Definition.writeValue(val));
        }
        for (int i = 1; i < count; i++) {
            sb.append(Separator);
            val = list.get(i);
            if (val != null) {
                sb.append(Definition.writeValue(val));
            }
        }
        return sb.toString();
    }

}

==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/tools/versit/valuedefinitions/rfc2425/ListValueDefinition.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.versit.valuedefinitions.rfc2425;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import com.openexchange.tools.versit.Property;
import com.openexchange.tools.versit.StringScanner;
import com.openexchange.tools.versit.ValueDefinition;

/**
 * @author Viktor Pracht
 */
public class ListValueDefinition extends ValueDefinition {

    private final char Separator;

    private final ValueDefinition Definition;

    public ListValueDefinition(final char separator, final ValueDefinition definition) {
        Separator = separator;
        Definition = definition;
    }

    @Override
    public Object createValue(final StringScanner s, final Property property) throws IOException {
        final ArrayList<Object> retval = new ArrayList<Object>();
        while (true) {
            final Object val = Definition.createValue(s, property);
            retval.add(val);
            if (s.peek != Separator) {
                break;
            }
            s.read();
        }
        return retval.isEmpty() ? null : retval;
    }

    @Override
    public String writeValue(final Object value) {
        final List<?> list = (ArrayList<?>) value;
        final int count = list.size();
        if (count == 0) {
            return "";
        }
        final StringBuilder sb = new StringBuilder();
        Object val = list.get(0);
        if (val != null) {
            sb.append(Definition.writeValue(val));
        }
        for (int i = 1; i < count; i++) {
            sb.append(Separator);
            val = list.get(i);
            if (val != null) {
                sb.append(Definition.writeValue(val));
            }
        }
        return sb.toString();
    }

}
